{% extends 'costs/base.html' %}

{% block body %}
    <ul>
        {% for company in companies %}
            <li>
                <a href="{% url 'employee_info_browser:organisation' %}?company={{ company.companyCode }}">{{ company }}</a>
            </li>
        {% endfor %}
    </ul>
{% endblock %}