<!DOCTYPE html>
<html lang="en">
<head>
    <meta charset="UTF-8">
    <title>{{ title }}</title>
    {% block head %}
    {% endblock %}
</head>
<body>
{% block body %}
{% endblock %}
</body>
</html>