<form action="{% url 'employee_info_browser:resource' %}">
    <label for="company">Firma</label>
    <select id="company" name="company">
        {% for company in companies %}
            {% if company.companyCode == company_select %}
                <option selected="selected" value="{{ company.companyCode }}">{{ company.companyCode }}</option>
            {% else %}
                <option value="{{ company.companyCode }}">{{ company.companyCode }}</option>
            {% endif %}
        {% endfor %}
    </select>
    <br/>

    <label>
        Ressursnummer
        <input name="employee" type="text">
    </label>
    <br/>
    <input type="submit" value="Vis ansatt">
</form>