{% load static %}
{% if value %}
    <img height="15px" src="{% static 'employee_info/check.svg' %}" alt="Ja">
{% else %}
    <img height="15px" src="{% static 'employee_info/cross.svg' %}" alt="Nei">
{% endif %}